@@ -62,6 +62,8 @@ pub mod gcode_file;
 pub use self::gcode_file::GcodeFile;
 pub mod license;
 pub use self::license::License;
+pub mod license_credentials;
+pub use self::license_credentials::LicenseCredentials;
 pub mod license_request;
 pub use self::license_request::LicenseRequest;
 pub mod mobile_auth_request;
@@ -250,12 +252,14 @@ pub mod remote_control_command_request;
 pub use self::remote_control_command_request::RemoteControlCommandRequest;
 pub mod software_enum;
 pub use self::software_enum::SoftwareEnum;
-pub mod status_enum;
-pub use self::status_enum::StatusEnum;
 pub mod system_task;
 pub use self::system_task::SystemTask;
 pub mod system_task_request;
 pub use self::system_task_request::SystemTaskRequest;
+pub mod system_task_status;
+pub use self::system_task_status::SystemTaskStatus;
+pub mod system_task_type;
+pub use self::system_task_type::SystemTaskType;
 pub mod telemetry_event;
 pub use self::telemetry_event::TelemetryEvent;
 pub mod telemetry_event_event_type_enum;
@@ -268,8 +272,6 @@ pub mod telemetry_event_request;
 pub use self::telemetry_event_request::TelemetryEventRequest;
 pub mod token_response;
 pub use self::token_response::TokenResponse;
-pub mod type_enum;
-pub use self::type_enum::TypeEnum;
 pub mod user;
 pub use self::user::User;
 pub mod user_request;
